// Copyright 2015 Google Inc.

#import <GoogleCastRemoteDisplay/GCKVideoFrameInput.h>

@class AVPlayerItem;

GCK_ASSUME_NONNULL_BEGIN

/**
 * AVPlayerItem tap that redirects video to a Remote Display session.
 *
 * Using GCKAVPlayerItemVideoTap, the final video composition of an AVPlayerItem can be redirected
 * to a Remote Display session. Together with GCKAVPlayerItemAudioTap, this allows to send media
 * playing on the local device to a Remote Display receiver.
 *
 * @ingroup RemoteDisplay
 */
GCK_EXPORT
@interface GCKAVPlayerItemVideoTap : GCKVideoFrameInput

/**
 * The tap's player item.
 *
 * After setting this property, the tap will start redirecting the final video composite of the
 * player item to its Remote Display session until the tap is reset, deallocated or another player
 * item is set.
 */
@property(nonatomic, GCK_NULLABLE) AVPlayerItem *playerItem;

/**
 * Reset the video tap.
 *
 * Frees all internal resources. The video tap can be used again after calling this method by
 * setting a new player item.
 */
- (void)reset;

@end

GCK_ASSUME_NONNULL_END
