// Copyright 2015 Google Inc.

#import <GoogleCastRemoteDisplay/GCKVideoFrameInput.h>

@class UIView;

GCK_ASSUME_NONNULL_BEGIN

/**
 * @class GCKViewVideoFrameInput
 *
 * Specialization of GCKVideoFrameInput for UIKit views.
 *
 * This video frame input makes it easier to mirror a UIKit view with Remote Display. Unlike the
 * OpenGL ES and Metal video frame inputs, this frame input performs most of the work on your
 * behalf. It will create a display link attached to the screen of its input view and start
 * snapshotting the view with a frame interval of 3. This will yield a 15 fps stream.
 *
 * You may change the view at any time. The frame input maintains a weak reference to its target
 * view to ensure it does not keep view objects alive past their normal lifetime. Setting the view
 * to nil will invalidate any existing display link.
 *
 * @sa GCKRemoteDisplaySession
 *
 * @section view_limits Limitations
 *
 * The performance of this frame input is severely limited by view snapshot APIs. It is very costly
 * to capture the contents of a view hierarchy and the cost is directly related to the complexity
 * of the view tree. You may get better performance by rasterizing views you intend to mirror.
 *
 * Views that are not owned by the app process cannot be mirrored. This includes keyboards and other
 * remove views such as those provided by app extensions. The view must be onscreen. See the
 * documentation for the UISnapshotting category for more information.
 *
 * Because this frame input interacts with UIKit, it can only be used from the main thread.
 *
 * @ingroup RemoteDisplay
 */
GCK_EXPORT
@interface GCKViewVideoFrameInput : GCKVideoFrameInput

/** The view to stream. May be a UIWindow. */
@property(nonatomic, weak, GCK_NULLABLE) UIView *view;

/** Proxy for the paused property of the driving CADisplayLink. Defaults to NO. */
@property(getter=isPaused, nonatomic) BOOL paused;

/** Proxy for the frameInterval property of the driving CADisplayLink. Defaults to 3. */
@property(nonatomic) NSInteger frameInterval;

@end

GCK_ASSUME_NONNULL_END
